@@ -1,8 +1,7 @@
 ;;; api.scm  --  The style for documenting Scheme APIs.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
 ;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012,
-;;;   2015, 2018 Ludovic Courts <ludo@gnu.org>
+;;;   2015, 2018, 2020 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
@@ -22,23 +21,23 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo documentation api)
-  :use-module (skribilo reader)
-  :use-module (skribilo engine)
-  :use-module (skribilo writer)
-  :use-module (skribilo ast)
-  :use-module (skribilo output)
-  :use-module (skribilo lib) ;; `define-markup'
-  :use-module (skribilo utils compat)
-  :use-module (skribilo utils syntax)
-  :use-module (skribilo utils justify)            ; for `info'
+  #:use-module (skribilo reader)
+  #:use-module (skribilo engine)
+  #:use-module (skribilo writer)
+  #:use-module (skribilo ast)
+  #:use-module (skribilo output)
+  #:use-module (skribilo lib) ;; `define-markup'
+  #:use-module (skribilo utils compat)
+  #:use-module (skribilo utils syntax)
+  #:use-module (skribilo utils justify)            ; for `info'
 
-  :use-module (skribilo package base)
-  :use-module (skribilo documentation manual)
-  :use-module (skribilo documentation env) ;; `*api-engines*'
+  #:use-module (skribilo package base)
+  #:use-module (skribilo documentation manual)
+  #:use-module (skribilo documentation env) ;; `*api-engines*'
 
-  :use-module (srfi srfi-1)
-  :use-module (ice-9 match)
-  :use-module (ice-9 optargs))
+  #:use-module (srfi srfi-1)
+  #:use-module (ice-9 match)
+  #:use-module (ice-9 optargs))
 
 (skribilo-module-syntax)
 
@@ -274,8 +273,7 @@ def @SkribiloExample named @Title {} right x {
               (let ((protos (markup-option n 'prototypes))
                     (opts   (markup-option n 'options))
                     (params (markup-option n 'parameters))
-                    (see    (markup-option n 'see-also))
-                    (margin *margin*))
+                    (see    (markup-option n 'see-also)))
                 (output (linebreak) e)
 
                 (with-justification
@@ -285,7 +283,7 @@ def @SkribiloExample named @Title {} right x {
                                (output "-- Markup: " e)
                                (output p e))
                              protos))
-                 (+ *margin* 1))
+                 1)
 
                 (and (pair? opts)
                      (output
@@ -392,7 +390,7 @@ def @SkribiloExample named @Title {} right x {
        o)
       (('define-simple-container (? (lambda (x) (eq? x id))))
        o)
-      (else
+      (_
        #f)))
 
 ;*---------------------------------------------------------------------*/
@@ -414,8 +412,7 @@ def @SkribiloExample named @Title {} right x {
 		    (make-engine? id (cdr exp))))
 	       (else
 		(make-engine? id exp)))))
-      (else
-       #f)))
+      (_ #f)))
 
 ;*---------------------------------------------------------------------*/
 ;*    make-engine-custom ...                                           */
@@ -427,8 +424,7 @@ def @SkribiloExample named @Title {} right x {
        custom)
       (((custom) _ ___)
        (primitive-eval custom))
-      (else
-       '()))))
+      (_ '()))))
 
 ;*---------------------------------------------------------------------*/
 ;*    define-markup-formals ...                                        */
@@ -454,7 +450,7 @@ def @SkribiloExample named @Title {} right x {
        '())
       (('define-simple-container _)
        '())
-      (else
+      (_
        (skribe-error 'define-markup-formals
 		     "Invalid 'define-markup' form"
 		     def))))
@@ -477,7 +473,7 @@ def @SkribiloExample named @Title {} right x {
        '((ident #f) (class #f)))
       (('define-simple-container _)
        '((ident #f) (class #f)))
-      (else
+      (_
        (skribe-error 'define-markup-options
 		     "Invalid 'define-markup' form"
 		     def))))
@@ -508,7 +504,7 @@ def @SkribiloExample named @Title {} right x {
        'node)
       (('define-simple-container _)
        'node)
-      (else
+      (_
        (skribe-error 'define-markup-rest
 		     "Invalid 'define-markup' form"
 		     def))))
@@ -570,7 +566,7 @@ def @SkribiloExample named @Title {} right x {
        (match exp
           (('quote (? symbol? sym))
 	   (string-append "'" (symbol->string sym)))
-	  (else
+	  (_
 	   (with-output-to-string (lambda () (write exp))))))))
 
 ;*---------------------------------------------------------------------*/
