@@ -21,26 +21,26 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo documentation manual)
-  :use-module (skribilo engine)
-  :use-module (skribilo writer)
-  :use-module (skribilo ast)
-  :use-module (skribilo lib)
-  :use-module (skribilo output)
-  :use-module (skribilo resolve)
-  :use-module (skribilo evaluator)
-  :use-module (skribilo utils keywords)
-  :use-module (skribilo utils syntax)
+  #:use-module (skribilo engine)
+  #:use-module (skribilo writer)
+  #:use-module (skribilo ast)
+  #:use-module (skribilo lib)
+  #:use-module (skribilo output)
+  #:use-module (skribilo resolve)
+  #:use-module (skribilo evaluator)
+  #:use-module (skribilo utils keywords)
+  #:use-module (skribilo utils syntax)
 
-  :use-module (skribilo documentation env)
-  :use-module (skribilo package base)
-  :use-module (skribilo source lisp)
-  :use-module (skribilo source xml)
+  #:use-module (skribilo documentation env)
+  #:use-module (skribilo package base)
+  #:use-module (skribilo source lisp)
+  #:use-module (skribilo source xml)
 
-  :use-module (oop goops)
-  :use-module (ice-9 optargs)
-  :use-module (srfi srfi-1)
-  :use-module (srfi srfi-13)
-  :use-module (srfi srfi-37))
+  #:use-module (oop goops)
+  #:use-module (ice-9 optargs)
+  #:use-module (srfi srfi-1)
+  #:use-module (srfi srfi-13)
+  #:use-module (srfi srfi-37))
 
 (skribilo-module-syntax)
 
