@@ -1,7 +1,7 @@
 ;;; skribilo.scm  --  The Skribilo document processor.
 ;;;
 ;;; Copyright 2005, 2006, 2007, 2008, 2009, 2011, 2012, 2013,
-;;;   2015, 2016, 2018  Ludovic Courts <ludo@gnu.org>
+;;;   2015, 2016, 2018, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
 ;;;
 ;;;
@@ -31,22 +31,22 @@
 
 
 (define-module (skribilo)
-  :autoload    (skribilo module) (make-user-module *skribilo-user-module*)
-  :autoload    (skribilo engine) (*current-engine*)
-  :autoload    (skribilo reader) (*document-reader*)
+  #:autoload    (skribilo module) (make-user-module *skribilo-user-module*)
+  #:use-module  (skribilo engine)
+  #:use-module  (skribilo reader)
 
-  :use-module  (skribilo utils syntax)
-  :use-module  (skribilo evaluator)
-  :use-module  (skribilo debug)
-  :use-module  (skribilo parameters)
-  :use-module  (skribilo config)
+  #:use-module  (skribilo utils syntax)
+  #:use-module  (skribilo evaluator)
+  #:use-module  (skribilo debug)
+  #:use-module  (skribilo parameters)
+  #:use-module  (skribilo config)
 
-  :use-module  (srfi srfi-1)
-  :use-module  (srfi srfi-13)
-  :use-module  (srfi srfi-37)
-  :use-module  (srfi srfi-39)
+  #:use-module  (srfi srfi-1)
+  #:use-module  (srfi srfi-13)
+  #:use-module  (srfi srfi-37)
+  #:use-module  (srfi srfi-39)
 
-  :export (skribilo))
+  #:export (skribilo))
 
 
 ;; Install the Skribilo module syntax reader.
@@ -419,7 +419,11 @@ options."
                             (open-output-file output-file)
                             (current-output-port))))
 
-          (setvbuf (*skribilo-output-port*) _IOFBF 16384)
+          (setvbuf (*skribilo-output-port*)
+                   (cond-expand
+                     (guile-2.2 'block)           ;Guile 2.2 and 3.0
+                     (else      _IOFBF))
+                   16384)
 
           (if input-file
               (with-input-from-file input-file
@@ -432,8 +436,4 @@ options."
           (force-output (*skribilo-output-port*)))))))
 
 
-;;; Local Variables:
-;;; coding: latin-1
-;;; End:
-
 ;;; skribilo ends here.
