@@ -1,7 +1,6 @@
 ;;; author.scm  --  Handling author names.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2006, 2007, 2008, 2009, 2015, 2018 Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2006, 2007, 2008, 2009, 2015, 2018, 2020 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -20,18 +19,18 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo biblio author)
-  :use-module (srfi srfi-13)
-  :use-module (srfi srfi-14)
-  :autoload   (srfi srfi-34)     (raise)
-  :use-module (srfi srfi-35)
-  :use-module (ice-9 match)
-  :use-module (skribilo biblio abbrev)
-  :autoload   (skribilo ast)     (markup-option markup-body markup-ident)
-  :autoload   (skribilo utils strings) (make-string-replace)
-  :autoload   (skribilo package base)  (it)
-  :use-module (skribilo utils syntax)
+  #:use-module (srfi srfi-13)
+  #:use-module (srfi srfi-14)
+  #:autoload   (srfi srfi-34)     (raise)
+  #:use-module (srfi srfi-35)
+  #:use-module (ice-9 match)
+  #:use-module (skribilo biblio abbrev)
+  #:use-module (skribilo ast)
+  #:autoload   (skribilo utils strings) (make-string-replace)
+  #:autoload   (skribilo package base)  (it)
+  #:use-module (skribilo utils syntax)
 
-  :export (comma-separated->author-list
+  #:export (comma-separated->author-list
 	   comma-separated->and-separated-authors
 
 	   extract-first-author-name
@@ -43,7 +42,7 @@
 
 	   bib-sort/first-author-last-name))
 
-;;; Author:  Ludovic Courts
+;;; Author:  Ludovic Courtès
 ;;;
 ;;; Commentary:
 ;;;
@@ -101,8 +100,8 @@
                                  #:optional (abbreviate-author-names
                                              abbreviate-author-first-names))
    ;; Abbreviate first names in NAMES.  NAMES is supposed to be
-   ;; something like "Ludovic Courts, Marc-Olivier Killijian".  The result
-   ;; is something like "L. Courts, M-O. Killijian".
+   ;; something like "Ludovic Courtès, Marc-Olivier Killijian".  The result
+   ;; is something like "L. Courtès, M-O. Killijian".
    (let loop ((names ((make-string-replace '((#\newline " ")
 					     (#\tab     " ")))
 		      names))
