@@ -1,6 +1,6 @@
 ;;; bibtex.scm  --  Handling BibTeX references.
 ;;;
-;;; Copyright 2006, 2007  Ludovic Courts <ludovic.courtes@laas.fr>
+;;; Copyright 2006, 2007, 2020 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -20,15 +20,15 @@
 
 
 (define-module (skribilo biblio bibtex)
-  :autoload   (skribilo utils strings) (make-string-replace)
-  :autoload   (skribilo ast)           (markup-option ast->string)
-  :autoload   (skribilo engine)        (engine-filter find-engine)
-  :use-module (skribilo biblio author)
-  :use-module (srfi srfi-39)
-  :use-module (srfi srfi-13)
-  :export     (print-as-bibtex-entry))
+  #:autoload   (skribilo utils strings) (make-string-replace)
+  #:use-module (skribilo ast)
+  #:autoload   (skribilo engine)        (engine-filter find-engine)
+  #:use-module (skribilo biblio author)
+  #:use-module (srfi srfi-39)
+  #:use-module (srfi srfi-13)
+  #:export     (print-as-bibtex-entry))
 
-;;; Author:  Ludovic Courts
+;;; Author:  Ludovic Courtès
 ;;;
 ;;; Commentary:
 ;;;
