@@ -1,7 +1,6 @@
 ;;; color.scm -- Color management.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2006, 2007  Ludovic Courts  <ludo@gnu.org>
+;;; Copyright 2006, 2007, 2020  Ludovic Courtès  <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@essi.fr>
 ;;;
 ;;;
@@ -22,11 +21,11 @@
 
 
 (define-module (skribilo color)
-  :use-module  (skribilo utils syntax)
-  :autoload    (skribilo ast) (search-down)
-  :autoload    (srfi srfi-1)  (append-map)
-  :autoload    (srfi srfi-60) (bitwise-and arithmetic-shift)
-  :export (color->rgb document-used-colors))
+  #:use-module  (skribilo utils syntax)
+  #:use-module  (skribilo ast)
+  #:autoload    (srfi srfi-1)  (append-map)
+  #:autoload    (srfi srfi-60) (bitwise-and arithmetic-shift)
+  #:export (color->rgb document-used-colors))
 
 (skribilo-module-syntax)
 
