@@ -2,6 +2,7 @@
 ;;;
 ;;; Copyright 2005, 2006, 2007, 2008, 2009, 2011, 2012, 2018, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
+;;; Copyright 2022, 2023 Arun Isaac <arunisaac@systemreboot.net>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -141,7 +142,7 @@
 	 :custom `(;; the icon associated with the URL
 		   (favicon #f)
 		   ;; charset used
-		   (charset "ISO-8859-1")
+		   (charset "UTF-8")
 		   ;; enable/disable Javascript
 		   (javascript #f)
 		   ;; user html head
@@ -188,8 +189,8 @@
 		   (chapter-number->string number->string)
 		   (chapter-file #f)
 		   ;; section configuration
-		   (section-title-start "<h3>")
-		   (section-title-stop "</h3>")
+		   (section-title-start "<h2>")
+		   (section-title-stop "</h2>")
 		   (section-title-background #f)
 		   (section-title-foreground #f)
 		   (section-title-number-separator " ")
@@ -631,7 +632,11 @@
              (display "<head>\n")
              (display "<meta http-equiv=\"Content-Type\" content=\"text/html;")
              (format #t "charset=~A\">\n" (engine-custom (find-engine 'html)
-                                                      'charset)))
+                                                         'charset))
+             (let ((head (engine-custom e 'head)))
+               (when head
+                 (display head)
+                 (newline))))
    :after "</head>\n\n")
 
 ;*---------------------------------------------------------------------*/
@@ -796,8 +801,7 @@
 (markup-writer '&html-header-style
    :before " <style type=\"text/css\">\n  <!--\n"
    :action (lambda (n e)
-	      (let ((hd (engine-custom e 'head))
-		    (icss (let ((ic (engine-custom e 'inline-css)))
+	      (let ((icss (let ((ic (engine-custom e 'inline-css)))
 			     (if (string? ic)
 				 (list ic)
 				 ic))))
@@ -809,7 +813,6 @@
 		 (display "  span.sc { font-variant: small-caps }\n")
 		 (display "  span.sf { font-family: sans-serif }\n")
 		 (display "  span.skribetitle { font-family: sans-serif; font-weight: bolder; font-size: x-large; }\n")
-		 (when hd (display (format #f "  ~a\n" hd)))
 		 (when (pair? icss)
 		    (for-each (lambda (css)
 				 (let ((p (open-input-file css)))
@@ -934,30 +937,28 @@
 	      (let ((footnotes (markup-body n)))
 		 (when (pair? footnotes)
 		    (display "<div class=\"skribilo-footnote\">")
-		    (display "<br><br>\n")
 		    (display "<hr width='20%' size='2' align='left'>\n"))))
    :action (lambda (n e)
-	      (let ((footnotes (markup-body n)))
-		 (when (pair? footnotes)
-		    (let loop ((fns footnotes))
-		       (if (pair? fns)
-			   (let ((fn (car fns)))
-                              (display "\n<div class=\"footnote\">")
+             (let ((footnotes (markup-body n)))
+               (for-each (lambda (fn)
+                           (display "\n<div class=\"footnote\">")
 
-                              ;; Note: the <a> tags must not be nested.
-			      (format #t "<a name=\"footnote-~a\"></a>"
-				      (string-canonicalize
-				       (container-ident fn)))
-                              (format #t "<a href=\"#footnote-site-~a\">"
-                                      (string-canonicalize
-                                       (container-ident fn)))
-                              (format #t "<sup><small>~a</small></sup></a>"
-                                      (markup-option fn :label))
-			      (output (markup-body fn) e)
+                           ;; Note: the <a> tags must not be nested.
 
-			      (display "\n</div>\n")
-			      (loop (cdr fns)))))
-		    (display "</div>")))))
+			   (format #t "<a name=\"footnote-~a\"></a>"
+				   (string-canonicalize
+				    (container-ident fn)))
+                           (format #t "<a href=\"#footnote-site-~a\">"
+                                   (string-canonicalize
+                                    (container-ident fn)))
+                           (format #t "<sup><small>~a</small></sup></a>"
+                                   (markup-option fn :label))
+			   (output (markup-body fn) e)
+
+			   (display "\n</div>\n"))
+                         footnotes)
+               (when (pair? footnotes)
+                 (display "</div>")))))
 
 ;*---------------------------------------------------------------------*/
 ;*    html-title-authors ...                                           */
@@ -1087,34 +1088,34 @@
 			     (display "<td></td>")
 			     (loop (+ i 1))))))
 	      (define (toc-entry fe level)
-		 (let* ((c (car fe))
-			(ch (cdr fe))
-			(id (markup-ident c))
-			(f (html-file c e)))
-		    (unless (string? id)
+                (match fe
+                  ((c ch ...)
+		   (let ((id (markup-ident c))
+		         (f (html-file c e)))
+		     (unless (string? id)
 		       (skribe-error 'toc
 				     (format #f "invalid identifier '~a'" id)
 				     c))
-		    (display " <tr>")
-		    ;; blank columns
-		    (col level)
-		    ;; number
-		    (format #t "<td valign=\"top\" align=\"left\">~a</td>"
-			    (html-container-number c e))
-		    ;; title
-		    (format #t "<td colspan=\"~a\" width=\"100%\">"
-			    (- 4 level))
-		    (format #t "<a href=\"~a#~a\">"
-			    (if (and (*destination-file*)
-				     (string=? f (*destination-file*)))
-				""
-				(strip-ref-base (or f (*destination-file*) "")))
-			    (string-canonicalize id))
-		    (output (markup-option c :title) e)
-		    (display "</a></td>")
-		    (display "</tr>\n")
-		    ;; the children
-		    (for-each (lambda (n) (toc-entry n (+ 1 level))) ch)))
+		     (display " <tr>")
+		     ;; blank columns
+		     (col level)
+		     ;; number
+		     (format #t "<td valign=\"top\" align=\"left\">~a</td>"
+			     (html-container-number c e))
+		     ;; title
+		     (format #t "<td colspan=\"~a\" width=\"100%\">"
+			     (- 4 level))
+		     (format #t "<a href=\"~a#~a\">"
+			     (if (and (*destination-file*)
+				      (string=? f (*destination-file*)))
+			         ""
+			         (strip-ref-base (or f (*destination-file*) "")))
+			     (string-canonicalize id))
+		     (output (markup-option c :title) e)
+		     (display "</a></td>")
+		     (display "</tr>\n")
+		     ;; the children
+		     (for-each (lambda (n) (toc-entry n (+ 1 level))) ch)))))
 
 	      (let* ((c (markup-option n :chapter))
 		     (s (markup-option n :section))
@@ -1305,8 +1306,7 @@
 		 (output (html-container-number n e) e)
 		 (display " ")
 		 (output (markup-option n :title) e)
-		 (display "</h1></center>")))
-   :after "<br>")
+		 (display "</h1></center>"))))
 
 ;; This writer is invoked only for chapters rendered inside separate files!
 (markup-writer 'chapter
@@ -1366,7 +1366,7 @@
 (markup-writer 'section
    :options '(:title :html-title :number :toc :file :env)
    :before html-section-title
-   :after "</div><br>\n")
+   :after "</div>\n")
 
 ;; on-file section writer
 (markup-writer 'section
