@@ -1,7 +1,7 @@
 ;;; latex.scm  --  LaTeX engine.
 ;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2007, 2009, 2012, 2015  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2007, 2009, 2012, 2015, 2020  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
@@ -21,24 +21,24 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo engine latex)
-  :use-module (skribilo lib)
-  :use-module (skribilo ast)
-  :use-module (skribilo engine)
-  :use-module (skribilo writer)
-  :use-module (skribilo location)
-  :use-module (skribilo utils strings)
-  :use-module (skribilo utils syntax)
-  :use-module (skribilo package base)
-  :autoload   (skribilo utils images)  (convert-image)
-  :autoload   (skribilo evaluator)     (evaluate-document)
-  :autoload   (skribilo output)        (output)
-  :autoload   (skribilo debug)         (*debug*)
-  :autoload   (skribilo color)         (color->rgb)
-  :use-module (srfi srfi-13)
-  :use-module (ice-9 optargs)
-  :use-module (ice-9 receive)
+  #:use-module (skribilo lib)
+  #:use-module (skribilo ast)
+  #:use-module (skribilo engine)
+  #:use-module (skribilo writer)
+  #:use-module (skribilo location)
+  #:use-module (skribilo utils strings)
+  #:use-module (skribilo utils syntax)
+  #:use-module (skribilo package base)
+  #:autoload   (skribilo utils images)  (convert-image)
+  #:autoload   (skribilo evaluator)     (evaluate-document)
+  #:autoload   (skribilo output)        (output)
+  #:autoload   (skribilo debug)         (*debug*)
+  #:autoload   (skribilo color)         (color->rgb)
+  #:use-module (srfi srfi-13)
+  #:use-module (ice-9 optargs)
+  #:use-module (ice-9 receive)
 
-  :export (latex-engine
+  #:export (latex-engine
            LaTeX TeX !latex
            skribe-color->latex-rgb))
 
@@ -519,14 +519,11 @@
 		     (begin (display dc) (newline))
 		     (display "\\documentclass{article}\n")))
 
-              (cond-expand
-               (guile-2
-                (let ((encoding (engine-custom e 'encoding)))
-                  (set-port-encoding! (current-output-port) encoding)
-                  (set-port-conversion-strategy! (current-output-port) 'error)
-                  (if (string-ci=? encoding "UTF-8") ; FIXME: other encodings?
-                      (display "\\usepackage[utf8]{inputenc}\n"))))
-               (else #t))
+              (let ((encoding (engine-custom e 'encoding)))
+                (set-port-encoding! (current-output-port) encoding)
+                (set-port-conversion-strategy! (current-output-port) 'error)
+                (when (string-ci=? encoding "UTF-8") ; FIXME: other encodings?
+                  (display "\\usepackage[utf8]{inputenc}\n")))
 
 	      (if (latex-color? e)
 		  (display (engine-custom e 'color-usepackage)))
