@@ -20,26 +20,26 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo package diff)
-  :use-module (diff)
-  :use-module (srfi srfi-1)
-  :use-module (srfi srfi-14)
-  :use-module (srfi srfi-39)
-  :use-module (ice-9 optargs)
+  #:use-module (diff)
+  #:use-module (srfi srfi-1)
+  #:use-module (srfi srfi-14)
+  #:use-module (srfi srfi-39)
+  #:use-module (ice-9 optargs)
 
-  :use-module (skribilo ast)
-  :use-module (skribilo lib)
-  :use-module (skribilo engine)
-  :use-module (skribilo writer)
-  :autoload   (skribilo output)        (output)
-  :autoload   (skribilo reader)        (*document-reader*)
-  :autoload   (skribilo module)        (make-user-module)
-  :autoload   (skribilo resolve)       (resolve!)
-  :autoload   (skribilo evaluator)     (evaluate-ast-from-port)
-  :autoload   (skribilo biblio)        (*bib-table* make-bib-table)
-  :use-module (skribilo package base)
-  :use-module (skribilo utils syntax)
+  #:use-module (skribilo ast)
+  #:use-module (skribilo lib)
+  #:use-module (skribilo engine)
+  #:use-module (skribilo writer)
+  #:autoload   (skribilo output)        (output)
+  #:autoload   (skribilo reader)        (*document-reader*)
+  #:autoload   (skribilo module)        (make-user-module)
+  #:autoload   (skribilo resolve)       (resolve!)
+  #:autoload   (skribilo evaluator)     (evaluate-ast-from-port)
+  #:autoload   (skribilo biblio)        (*bib-table* make-bib-table)
+  #:use-module (skribilo package base)
+  #:use-module (skribilo utils syntax)
 
-  :export (make-diff-document
+  #:export (make-diff-document
            make-diff-document-from-files))
 
 (skribilo-module-syntax)
