@@ -1,6 +1,6 @@
 ;;; justify.scm  --  Producing justified text.
 ;;;
-;;; Copyright 2008  Ludovic Courtès <ludo@gnu.org>
+;;; Copyright 2008, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2001  Manuel Serrano
 ;;;
 ;;;
@@ -20,11 +20,11 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo utils justify)
-  :use-module (srfi srfi-13)
-  :autoload   (srfi srfi-34)       (raise)
-  :use-module (srfi srfi-35)
-  :use-module (skribilo condition)
-  :export (make-justifier output-flush
+  #:use-module (srfi srfi-13)
+  #:autoload   (srfi srfi-34)       (raise)
+  #:use-module (srfi srfi-35)
+  #:use-module (skribilo condition)
+  #:export (make-justifier output-flush
 
 	   *text-column-width*
 	   *text-justification*
@@ -90,13 +90,13 @@
 			  (lambda ()
 			     (output-justified str)))))
 
-(define *margin* 0)
+(define *margin* (make-parameter 0))
 
 ;*---------------------------------------------------------------------*/
 ;*    output ...                                                       */
 ;*---------------------------------------------------------------------*/
 (define (output-justified str)
-   ((car *justifiers*) 'output str))
+   ((*justifier*) 'output str))
 
 ;*---------------------------------------------------------------------*/
 ;*    output-token ...                                                 */
@@ -105,13 +105,13 @@
 ;*    contains #\spaces.                                               */
 ;*---------------------------------------------------------------------*/
 (define (output-token str)
-   ((car *justifiers*) 'output (string-replace-char str #\space #\bs)))
+   ((*justifier*) 'output (string-replace-char str #\space #\bs)))
 
 ;*---------------------------------------------------------------------*/
 ;*    output-newline ...                                               */
 ;*---------------------------------------------------------------------*/
 (define (output-newline)
-   ((car *justifiers*) 'newline))
+   ((*justifier*) 'newline))
 
 ;*---------------------------------------------------------------------*/
 ;*    output-flush ...                                                 */
@@ -126,39 +126,36 @@
 		 (lambda (x)
                    (display (text-string x))
                    (newline)))
-	     ((car *justifiers*) 'flush)))
+	     ((*justifier*) 'flush)))
 
 ;*---------------------------------------------------------------------*/
 ;*    justification-width ...                                          */
 ;*---------------------------------------------------------------------*/
 (define (justification-width)
-   ((car *justifiers*) 'width))
+   ((*justifier*) 'width))
 
 ;*---------------------------------------------------------------------*/
 ;*    with-justification ...                                           */
 ;*---------------------------------------------------------------------*/
-(define (with-justification justifier thunk . margin)
-   (output-flush *margin*)
-   (let ((old-margin *margin*))
-      (if (pair? margin) (set! *margin* (+ *margin* (car margin))))
-      (set! *justifiers* (cons justifier *justifiers*))
-      (thunk)
-      (output-flush *margin*)
-      (set! *justifiers* (cdr *justifiers*))
-      (set! *margin* old-margin)))
+(define* (with-justification justifier thunk #:optional margin)
+  (output-flush (*margin*))
+  (parameterize ((*margin* (if margin
+                               (+ (*margin*) margin)
+                               (*margin*)))
+                 (*justifier* justifier))
+    (thunk)
+    (output-flush (*margin*))))
 
 ;*---------------------------------------------------------------------*/
 ;*    with-justification/noflush ...                                   */
 ;*---------------------------------------------------------------------*/
-(define (with-justification/noflush justifier thunk . margin)
-   (let ((old-margin *margin*))
-      (if (pair? margin) (set! *margin* (+ *margin* (car margin))))
-      (set! *justifiers* (cons justifier *justifiers*))
-      (thunk)
-      (let ((res ((car *justifiers*) 'flush)))
-	 (set! *justifiers* (cdr *justifiers*))
-	 (set! *margin* old-margin)
-	 res)))
+(define* (with-justification/noflush justifier thunk #:optional margin)
+  (parameterize ((*margin* (if margin
+                               (+ (*margin*) margin)
+                               (*margin*)))
+                 (*justifier* justifier))
+    (thunk)
+    ((*justifier*) 'flush)))
 
 ;*---------------------------------------------------------------------*/
 ;*    *spaces* ...                                                     */
@@ -415,11 +412,9 @@
 		   (else
 		    (error "justifier" "Invalid command" cmd))))))))
 
-;*---------------------------------------------------------------------*/
-;*    *justifiers* ...                                                 */
-;*---------------------------------------------------------------------*/
-(define *justifiers* (list (make-justifier *text-column-width*
-					   *text-justification*)))
+(define *justifier*
+  (make-parameter (make-justifier *text-column-width*
+				  *text-justification*)))
 
 
 ;;; justify.scm ends here
